# pysynic
Synthetic data generator for Python.

Creating synthetic data is often domain specific but often there are common requirements 
(for example, that a number or a date should be randomly within a range). 

This package facilitates that but really we advocate the philosophy of creating synthetic data
to test your pipelines and machine learning models etc.
